@@ -17,7 +17,7 @@
 # Date:		Sat Oct 17 22:33:40 1998
 # Description:	test stuff for Tree::Radix
 #
-# $Id: test.pl,v 1.2 1999/11/17 05:19:28 hag Exp $
+# $Id: test.pl,v 1.3 1999/11/28 07:13:36 hag Exp $
 
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
@@ -46,14 +46,47 @@ print "ok 2\n";
 my $uname = `uname -n`;		# XXX Sys::Hostname ?
 chomp $uname;
 
-my $self_tr = $tr->new(host => $uname, timeout=>30,
-#		       debug => 9,
-		       ) || do { print "not ok 3\n" ; exit 1};
+my $tr_suceed = &test_tr($uname);
 
-if($self_tr->stat != TRACEROUTE_OK || ! $self_tr->found ||
-   $self_tr->hops != 1) {
+# Didn't work at all
+if(!defined($tr_suceed)) {
     print "not ok 3\n";
-    exit 1;
 }
 
-print "ok 3\n";
+if($tr_suceed != 0) {
+    print "ok 3\n";
+} else {
+    # Some OSes don't allow traceroute to localhost.  Ask the user
+    # for a host and do it again
+    {
+	local $| = 1;
+
+	print "Traceroute to $uname didn't work.\n";
+	print "Please name a host that you can traceroute: ";
+
+	my $testhost = <STDIN>;
+	chomp $testhost;
+
+	my $test_tr = &test_tr($testhost);
+	if(!$test_tr) {
+	    print "not ok 3\n";
+	} else {
+	    print "ok 3\n";
+	}
+    }
+}
+
+sub test_tr {
+    my $hostname = shift;
+
+    my $self_tr = $tr->new(host => $hostname, timeout=>30,
+#			   debug => 9,
+			   );
+
+    return() if(!$self_tr);
+
+    if($self_tr->stat != TRACEROUTE_OK || ! $self_tr->found) {
+	return 0;
+    }
+    return 1;
+}
